MidiChannel class
Prepares raw MIDI data for a specific channel.
This class encapsulates a single handle-channel pair and prepares the raw byte streams for various MIDI messages. This design allows for efficient batching of commands.
Constructors
- MidiChannel({required int handle, required int channel})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareChannelAftertouch(
int pressure) → Uint8List - Prepares a Channel Aftertouch message (0xD0) for this channel.
-
prepareControlChange(
int controller, int value) → Uint8List - Prepares a Control Change message (0xB0) for this channel.
-
prepareNoteOff(
int note, int velocity) → Uint8List - Prepares a Note Off message (0x80) for this channel.
-
prepareNoteOn(
int note, int velocity) → Uint8List - Prepares a Note On message (0x90) for this channel.
-
preparePitchBend(
int value) → Uint8List - Prepares a Pitch Bend message (0xE0) for this channel.
-
preparePolyAftertouch(
int note, int pressure) → Uint8List - Prepares a Polyphonic Aftertouch message (0xA0) for this channel.
-
prepareProgramChange(
int program) → Uint8List - Prepares a Program Change message (0xC0) for this channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited